@@ -4,6 +4,7 @@ module Moneta
     extend self
 
     def without(hash, *keys)
+      return hash if hash.empty?
       if keys.any? {|k| hash.include?(k) }
         hash = hash.dup
         keys.each {|k| hash.delete(k) }
@@ -11,6 +12,13 @@ module Moneta
       hash
     end
 
+    def only(hash, *keys)
+      return hash if hash.empty?
+      ret = {}
+      keys.each {|k| ret[k] = hash[k] }
+      ret
+    end
+
     def to_int(value)
       intvalue = value.to_i
       raise "#{value.inspect} is not an integer value" unless value == nil || intvalue.to_s == value.to_s
